==> gpointing-device-settings-1.1.0.tar.gz: gpointing-device-settings-1.1.0/modules/common/gpds-touchpad-definitions.h <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 *  Copyright (C) 2009 Hiroyuki Ikezoe  <poincare@ikezoe.net>
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __GPDS_TOUCHPAD_GCONF_H__
#define __GPDS_TOUCHPAD_GCONF_H__

#define GPDS_TOUCHPAD_EDGES_KEY                           "edges"
#define GPDS_TOUCHPAD_FINGER_KEY                          "finger"
#define GPDS_TOUCHPAD_OFF_KEY                             "off"
#define GPDS_TOUCHPAD_TAP_TIME_KEY                        "tap_time"
#define GPDS_TOUCHPAD_TAP_FAST_TAP_KEY                    "tap_fast_tap"
#define GPDS_TOUCHPAD_HORIZONTAL_SCROLLING_DISTANCE_KEY   "horizontal_scrolling_distance"
#define GPDS_TOUCHPAD_HORIZONTAL_SCROLLING_KEY            "horizontal_scrolling"
#define GPDS_TOUCHPAD_VERTICAL_SCROLLING_DISTANCE_KEY     "vertical_scrolling_distance"
#define GPDS_TOUCHPAD_VERTICAL_SCROLLING_KEY              "vertical_scrolling"
#define GPDS_TOUCHPAD_TWO_FINGER_VERTICAL_SCROLLING_KEY   "two_finger_vertical_scrolling"
#define GPDS_TOUCHPAD_TWO_FINGER_HORIZONTAL_SCROLLING_KEY "two_finger_horizontal_scrolling"
#define GPDS_TOUCHPAD_CONTINUOUS_EDGE_SCROLLING_KEY       "continuous_edge_scrolling"
#define GPDS_TOUCHPAD_CIRCULAR_SCROLLING_KEY              "circular_scrolling"
#define GPDS_TOUCHPAD_CIRCULAR_SCROLLING_DISTANCE_KEY     "circular_scrolling_distance"
#define GPDS_TOUCHPAD_CIRCULAR_SCROLLING_TRIGGER_KEY      "circular_scrolling_trigger"

#endif /* __GPDS_TOUCHPAD_GCONF_H__ */
/*
vi:ts=4:nowrap:ai:expandtab:sw=4
*/

==> gpointing-device-settings_1.3.2.orig.tar.gz: gpointing-device-settings-1.3.2/modules/common/gpds-touchpad-definitions.h <==
/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 *  Copyright (C) 2009 Hiroyuki Ikezoe  <poincare@ikezoe.net>
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __GPDS_TOUCHPAD_GCONF_H__
#define __GPDS_TOUCHPAD_GCONF_H__

#define GPDS_TOUCHPAD_OFF_KEY                             "off"
#define GPDS_TOUCHPAD_GUEST_MOUSE_OFF_KEY                 "guest_mouse"
#define GPDS_TOUCHPAD_TAP_TIME_KEY                        "tap_time"
#define GPDS_TOUCHPAD_TAP_MOVE_KEY                        "tap_move"
#define GPDS_TOUCHPAD_TAP_FAST_TAP_KEY                    "tap_fast_tap"
#define GPDS_TOUCHPAD_HORIZONTAL_SCROLLING_DISTANCE_KEY   "horizontal_scrolling_distance"
#define GPDS_TOUCHPAD_HORIZONTAL_SCROLLING_KEY            "horizontal_scrolling"
#define GPDS_TOUCHPAD_VERTICAL_SCROLLING_DISTANCE_KEY     "vertical_scrolling_distance"
#define GPDS_TOUCHPAD_VERTICAL_SCROLLING_KEY              "vertical_scrolling"
#define GPDS_TOUCHPAD_TWO_FINGER_VERTICAL_SCROLLING_KEY   "two_finger_vertical_scrolling"
#define GPDS_TOUCHPAD_TWO_FINGER_HORIZONTAL_SCROLLING_KEY "two_finger_horizontal_scrolling"
#define GPDS_TOUCHPAD_CONTINUOUS_EDGE_SCROLLING_KEY       "continuous_edge_scrolling"
#define GPDS_TOUCHPAD_CIRCULAR_SCROLLING_KEY              "circular_scrolling"
#define GPDS_TOUCHPAD_CIRCULAR_SCROLLING_DISTANCE_KEY     "circular_scrolling_distance"
#define GPDS_TOUCHPAD_CIRCULAR_SCROLLING_TRIGGER_KEY      "circular_scrolling_trigger"
#define GPDS_TOUCHPAD_PALM_DETECTION_KEY                  "palm_detection"
#define GPDS_TOUCHPAD_PALM_DETECTION_WIDTH_KEY            "palm_detection_width"
#define GPDS_TOUCHPAD_PALM_DETECTION_DEPTH_KEY            "palm_detection_depth"
#define GPDS_TOUCHPAD_LOCKED_DRAGS_KEY                    "locked_drags"
#define GPDS_TOUCHPAD_LOCKED_DRAGS_TIMEOUT_KEY            "locked_drags_timeout"
#define GPDS_TOUCHPAD_CLICK_ACTION_FINGER1_KEY            "click_action_finger1"
#define GPDS_TOUCHPAD_CLICK_ACTION_FINGER2_KEY            "click_action_finger2"
#define GPDS_TOUCHPAD_CLICK_ACTION_FINGER3_KEY            "click_action_finger3"

#endif /* __GPDS_TOUCHPAD_GCONF_H__ */
/*
vi:ts=4:nowrap:ai:expandtab:sw=4
*/
